@@ -64,7 +64,7 @@ SETTING_SCROLL_MARGIN = 'scroll-margin'
 SETTING_SHOW_NUMBERS = 'show-numbers'
 SETTING_USE_COLORS = 'use-colors'
 SETTING_TASK_FORMAT = 'task-format'
-SETTING_CLEAR_CONTEXT = 'clear-context'
+SETTING_CLEAR_CONTEXT = 'clear-contexts'
 SETTING_FONT = 'font'
 SETTING_FONTSIZE = 'font-size'
 SETTING_SINGLE_INSTANCE = 'single-instance'
