@@ -278,6 +278,7 @@ class Window:
         self.status_bar = None
         self.help_bar = None
         self.sort_order = utils.build_sort_order(common.DEFAULT_SORT_ORDER)
+        self.sort_order_txt = common.DEFAULT_SORT_ORDER
         self.search = Searcher('',
                                self.conf.bool(common.SETTING_GROUP_GENERAL,
                                               common.SETTING_SEARCH_CASE_SENSITIVE),
@@ -510,10 +511,14 @@ class Window:
         self.help_bar.noutrefresh()
 
     def update_sorting(self):
+        new_sort_order = common.DEFAULT_SORT_ORDER
         for part in self.search.text.split(' '):
             if part.startswith('sort:'):
-                self.sort_order = utils.build_sort_order(part.split(':', 1)[1])
+                new_sort_order = part.split(':', 1)[1]
                 break
+        if self.sort_order_txt != new_sort_order:
+            self.sort_order_txt = new_sort_order
+            self.sort_order = utils.build_sort_order(new_sort_order)
         self.tasks.sort(key=lambda t: utils.sort_fnc(t, self.sort_order))
 
     def update_tasks(self):
@@ -873,10 +878,11 @@ class Window:
 
     def refresh_search_bar(self):
         self.search_bar.erase()
-        if len(self.search.text.strip()) == 0:
+        text = self.search.text.strip()
+        if len(text) == 0:
             self.search_bar.addstr(0, 1, tr('(no search active)'), self.color(common.SETTING_COL_INACTIVE))
         else:
-            self.search_bar.addstr(0, 1, self.search.text)
+            self.search_bar.addstr(0, 1, text[:curses.COLS-2])
         self.search_bar.refresh()
 
     def read_text(self, y, x, cols=None, text='', callback=None, select_source=None):
